@@ -20,7 +20,7 @@ from ciscoconfparse.ccp_abc import BaseCfgLine
 ###   THIS FILE IS NOT FULLY FUNCTIONAL.  IT IS INCOMPLETE
 ###
 ###   You have been warned :-)
-""" models_nxos.py - Parse, Query, Build, and Modify IOS-style configurations
+r""" models_nxos.py - Parse, Query, Build, and Modify IOS-style configurations
 
      Copyright (C) 2020-2021 David Michael Pennington at Cisco Systems
      Copyright (C) 2019      David Michael Pennington at ThousandEyes
@@ -52,7 +52,7 @@ MAX_VLAN = 4094
 
 
 class NXOSCfgLine(BaseCfgLine):
-    """An object for a parsed IOS-style configuration line.  
+    r"""An object for a parsed IOS-style configuration line.  
     :class:`~models_nxos.NXOSCfgLine` objects contain references to other 
     parent and child :class:`~models_nxos.NXOSCfgLine` objects.
 
@@ -75,7 +75,7 @@ class NXOSCfgLine(BaseCfgLine):
     """
 
     def __init__(self, *args, **kwargs):
-        """Accept an IOS line number and initialize family relationship
+        r"""Accept an IOS line number and initialize family relationship
         attributes"""
         super(NXOSCfgLine, self).__init__(*args, **kwargs)
 
@@ -87,7 +87,7 @@ class NXOSCfgLine(BaseCfgLine):
     @property
     def is_intf(self):
         # Includes subinterfaces
-        """Returns a boolean (True or False) to answer whether this 
+        r"""Returns a boolean (True or False) to answer whether this 
         :class:`~models_nxos.NXOSCfgLine` is an interface; subinterfaces
         also return True.
 
@@ -114,7 +114,7 @@ class NXOSCfgLine(BaseCfgLine):
            ...     '!',
            ...     ]
            >>> parse = CiscoConfParse(config)
-           >>> obj = parse.find_objects('^interface\sEthernet')[0]
+           >>> obj = parse.find_objects(r'^interface\sEthernet')[0]
            >>> obj.is_intf
            True
            >>>
@@ -127,7 +127,7 @@ class NXOSCfgLine(BaseCfgLine):
 
     @property
     def is_subintf(self):
-        """Returns a boolean (True or False) to answer whether this 
+        r"""Returns a boolean (True or False) to answer whether this 
         :class:`~models_nxos.NXOSCfgLine` is a subinterface.
 
         Returns:
@@ -174,7 +174,7 @@ class NXOSCfgLine(BaseCfgLine):
 
     @property
     def is_loopback_intf(self):
-        """Returns a boolean (True or False) to answer whether this 
+        r"""Returns a boolean (True or False) to answer whether this 
         :class:`~models_nxos.NXOSCfgLine` is a loopback interface.
 
         Returns:
@@ -210,7 +210,7 @@ class NXOSCfgLine(BaseCfgLine):
 
     @property
     def is_ethernet_intf(self):
-        """Returns a boolean (True or False) to answer whether this 
+        r"""Returns a boolean (True or False) to answer whether this 
         :class:`~models_nxos.NXOSCfgLine` is an ethernet interface.
         Any ethernet interface (10M through 10G) is considered an ethernet
         interface.
@@ -391,7 +391,7 @@ class BaseNXOSIntfLine(NXOSCfgLine):
 
     @property
     def abbvs(self):
-        """A python set of valid abbreviations (lowercased) for the interface"""
+        r"""A python set of valid abbreviations (lowercased) for the interface"""
         return self._build_abbvs()
 
     _INTF_NAME_RE_STR = r"^interface\s+(\S+[0-9\/\.\s]+)\s*"
@@ -399,7 +399,7 @@ class BaseNXOSIntfLine(NXOSCfgLine):
 
     @property
     def name(self):
-        """Return the interface name as a string, such as 'GigabitEthernet0/1'
+        r"""Return the interface name as a string, such as 'GigabitEthernet0/1'
 
         Returns:
             - str.  The interface name as a string, or '' if the object is not an interface.
@@ -424,13 +424,13 @@ class BaseNXOSIntfLine(NXOSCfgLine):
            ...     '!',
            ...     ]
            >>> parse = CiscoConfParse(config, factory=True)
-           >>> obj = parse.find_objects('^interface\sFast')[0]
+           >>> obj = parse.find_objects(r'^interface\sFast')[0]
            >>> obj.name
            'FastEthernet1/0'
-           >>> obj = parse.find_objects('^interface\sATM')[0]
+           >>> obj = parse.find_objects(r'^interface\sATM')[0]
            >>> obj.name
            'ATM2/0'
-           >>> obj = parse.find_objects('^interface\sATM')[1]
+           >>> obj = parse.find_objects(r'^interface\sATM')[1]
            >>> obj.name
            'ATM2/0.100'
            >>>
@@ -442,7 +442,7 @@ class BaseNXOSIntfLine(NXOSCfgLine):
 
     @property
     def port(self):
-        """Return the interface's port number
+        r"""Return the interface's port number
 
         Returns:
             - int.  The interface number.
@@ -467,10 +467,10 @@ class BaseNXOSIntfLine(NXOSCfgLine):
            ...     '!',
            ...     ]
            >>> parse = CiscoConfParse(config, factory=True)
-           >>> obj = parse.find_objects('^interface\sFast')[0]
+           >>> obj = parse.find_objects(r'^interface\sFast')[0]
            >>> obj.port
            0
-           >>> obj = parse.find_objects('^interface\sATM')[0]
+           >>> obj = parse.find_objects(r'^interface\sATM')[0]
            >>> obj.port
            0
            >>>
@@ -479,7 +479,7 @@ class BaseNXOSIntfLine(NXOSCfgLine):
 
     @property
     def port_type(self):
-        """Return Loopback, ATM, GigabitEthernet, Virtual-Template, etc...
+        r"""Return Loopback, ATM, GigabitEthernet, Virtual-Template, etc...
 
         Returns:
             - str.  The port type.
@@ -517,7 +517,7 @@ class BaseNXOSIntfLine(NXOSCfgLine):
 
     @property
     def ordinal_list(self):
-        """Return a tuple of numbers representing card, slot, port for this interface.  This method strips all subinterface information in the returned value.  If you call ordinal_list on GigabitEthernet2/25.100, you'll get this python tuple of integers: (2, 25).  If you call ordinal_list on GigabitEthernet2/0/25.100 you'll get this python list of integers: (2, 0, 25).
+        r"""Return a tuple of numbers representing card, slot, port for this interface.  This method strips all subinterface information in the returned value.  If you call ordinal_list on GigabitEthernet2/25.100, you'll get this python tuple of integers: (2, 25).  If you call ordinal_list on GigabitEthernet2/0/25.100 you'll get this python list of integers: (2, 0, 25).
 
         Returns:
             - tuple.  A tuple of port numbers as integers.
@@ -565,7 +565,7 @@ class BaseNXOSIntfLine(NXOSCfgLine):
 
     @property
     def interface_number(self):
-        """Return a string representing the card, slot, port for this interface.  If you call interface_number on GigabitEthernet2/25.100, you'll get this python string: '2/25'.  If you call interface_number on GigabitEthernet2/0/25.100 you'll get this python string '2/0/25'.  This method strips all subinterface information in the returned value.
+        r"""Return a string representing the card, slot, port for this interface.  If you call interface_number on GigabitEthernet2/25.100, you'll get this python string: '2/25'.  If you call interface_number on GigabitEthernet2/0/25.100 you'll get this python string '2/0/25'.  This method strips all subinterface information in the returned value.
 
         Returns:
             - string.
@@ -611,7 +611,7 @@ class BaseNXOSIntfLine(NXOSCfgLine):
 
     @property
     def subinterface_number(self):
-        """Return a string representing the card, slot, port for this interface or subinterface.  If you call subinterface_number on GigabitEthernet2/25.100, you'll get this python string: '2/25.100'.  If you call interface_number on GigabitEthernet2/0/25 you'll get this python string '2/0/25'.  This method strips all subinterface information in the returned value.
+        r"""Return a string representing the card, slot, port for this interface or subinterface.  If you call subinterface_number on GigabitEthernet2/25.100, you'll get this python string: '2/25.100'.  If you call interface_number on GigabitEthernet2/0/25 you'll get this python string '2/0/25'.  This method strips all subinterface information in the returned value.
 
         Returns:
             - string.
@@ -815,7 +815,7 @@ class BaseNXOSIntfLine(NXOSCfgLine):
     def manual_mtu(self):
         ## Due to the diverse platform defaults, this should be the
         ##    only mtu information I plan to support
-        """Returns a integer value for the manual MTU configured on an
+        r"""Returns a integer value for the manual MTU configured on an
         :class:`~models_nxos.NXOSIntfLine` object.  Interfaces without a
         manual MTU configuration return 0.
 
@@ -843,10 +843,10 @@ class BaseNXOSIntfLine(NXOSCfgLine):
            ...     '!',
            ...     ]
            >>> parse = CiscoConfParse(config, factory=True)
-           >>> obj = parse.find_objects('^interface\sFast')[0]
+           >>> obj = parse.find_objects(r'^interface\sFast')[0]
            >>> obj.manual_mtu
            0
-           >>> obj = parse.find_objects('^interface\sATM')[0]
+           >>> obj = parse.find_objects(r'^interface\sATM')[0]
            >>> obj.manual_mtu
            4470
            >>>
@@ -950,7 +950,7 @@ class BaseNXOSIntfLine(NXOSCfgLine):
         return False
 
     def in_ipv4_subnet(self, ipv4network=IPv4Obj("0.0.0.0/32", strict=False)):
-        """Accept an argument for the :class:`~ccp_util.IPv4Obj` to be 
+        r"""Accept an argument for the :class:`~ccp_util.IPv4Obj` to be 
         considered, and return a boolean for whether this interface is within 
         the requested :class:`~ccp_util.IPv4Obj`.
 
@@ -1052,7 +1052,7 @@ class BaseNXOSIntfLine(NXOSCfgLine):
         ## NOTE: I have no intention of checking self.is_shutdown here
         ##     People should be able to check the sanity of interfaces
         ##     before they put them into production
-        """Return a boolean for whether no ip proxy-arp is configured on the 
+        r"""Return a boolean for whether no ip proxy-arp is configured on the 
         interface.
 
         Returns:
@@ -1073,7 +1073,7 @@ class BaseNXOSIntfLine(NXOSCfgLine):
            ...     '!',
            ...     ]
            >>> parse = CiscoConfParse(config, factory=True)
-           >>> obj = parse.find_objects('^interface\sFast')[0]
+           >>> obj = parse.find_objects(r'^interface\sFast')[0]
            >>> obj.has_no_ip_proxyarp
            True
            >>>
@@ -1138,7 +1138,7 @@ class BaseNXOSIntfLine(NXOSCfgLine):
 
     @property
     def manual_arp_timeout(self):
-        """Return an integer with the current interface ARP timeout, if there isn't one set, return 0.  If there is no IP address, return -1"""
+        r"""Return an integer with the current interface ARP timeout, if there isn't one set, return 0.  If there is no IP address, return -1"""
         ## NOTE: I have no intention of checking self.is_shutdown here
         ##     People should be able to check the sanity of interfaces
         ##     before they put them into production
@@ -1156,14 +1156,14 @@ class BaseNXOSIntfLine(NXOSCfgLine):
 
     @property
     def has_ip_helper_addresses(self):
-        """Return a True if the intf has helper-addresses; False if not"""
+        r"""Return a True if the intf has helper-addresses; False if not"""
         if len(self.ip_helper_addresses) > 0:
             return True
         return False
 
     @property
     def ip_helper_addresses(self):
-        """Return a list of dicts with IP helper-addresses.  Each helper-address is in a dictionary.  The dictionary is in this format:
+        r"""Return a list of dicts with IP helper-addresses.  Each helper-address is in a dictionary.  The dictionary is in this format:
 
         .. code-block:: python
            :emphasize-lines: 11
@@ -1336,22 +1336,22 @@ class BaseNXOSIntfLine(NXOSCfgLine):
 
             ## For every child object, check whether the vlan list is modified
             abs_str = obj.re_match_typed(
-                "^\s+switchport\s+trunk\s+allowed\s+vlan\s(all|none|\d.*?)$",
+                r"^\s+switchport\s+trunk\s+allowed\s+vlan\s(all|none|\d.*?)$",
                 default="_nomatch_",
                 result_type=str,
             ).lower()
             add_str = obj.re_match_typed(
-                "^\s+switchport\s+trunk\s+allowed\s+vlan\s+add\s+(\d.*?)$",
+                r"^\s+switchport\s+trunk\s+allowed\s+vlan\s+add\s+(\d.*?)$",
                 default="_nomatch_",
                 result_type=str,
             ).lower()
             exc_str = obj.re_match_typed(
-                "^\s+switchport\s+trunk\s+allowed\s+vlan\s+except\s+(\d.*?)$",
+                r"^\s+switchport\s+trunk\s+allowed\s+vlan\s+except\s+(\d.*?)$",
                 default="_nomatch_",
                 result_type=str,
             ).lower()
             rem_str = obj.re_match_typed(
-                "^\s+switchport\s+trunk\s+allowed\s+vlan\s+remove\s+(\d.*?)$",
+                r"^\s+switchport\s+trunk\s+allowed\s+vlan\s+remove\s+(\d.*?)$",
                 default="_nomatch_",
                 result_type=str,
             ).lower()
@@ -1711,7 +1711,7 @@ class NXOSIntfGlobal(BaseCfgLine):
     @classmethod
     def is_object_for(cls, line="", re=re):
         if re.search(
-            "^(no\s+cdp\s+run)|(logging\s+event\s+link-status\s+global)|(spanning-tree\sportfast\sdefault)|(spanning-tree\sportfast\sbpduguard\sdefault)",
+            r"^(no\s+cdp\s+run)|(logging\s+event\s+link-status\s+global)|(spanning-tree\sportfast\sdefault)|(spanning-tree\sportfast\sbpduguard\sdefault)",
             line,
         ):
             return True
@@ -1719,25 +1719,25 @@ class NXOSIntfGlobal(BaseCfgLine):
 
     @property
     def has_cdp_disabled(self):
-        if self.re_search("^no\s+cdp\s+run\s*"):
+        if self.re_search(r"^no\s+cdp\s+run\s*"):
             return True
         return False
 
     @property
     def has_intf_logging_def(self):
-        if self.re_search("^logging\s+event\s+link-status\s+global"):
+        if self.re_search(r"^logging\s+event\s+link-status\s+global"):
             return True
         return False
 
     @property
     def has_stp_portfast_bpduguard_def(self):
-        if self.re_search("^spanning-tree\sportfast\sbpduguard\sdefault"):
+        if self.re_search(r"^spanning-tree\sportfast\sbpduguard\sdefault"):
             return True
         return False
 
     @property
     def has_stp_mode_rapidpvst(self):
-        if self.re_search("^spanning-tree\smode\srapid-pvst"):
+        if self.re_search(r"^spanning-tree\smode\srapid-pvst"):
             return True
         return False
 
@@ -1947,7 +1947,7 @@ class NXOSAccessLine(BaseCfgLine):
     def name(self):
         retval = self.re_match_typed(r"^line\s+(\S+)", result_type=str, default="")
         # special case for IOS async lines: i.e. "line 33 48"
-        if re.search("\d+", retval):
+        if re.search(r"\d+", retval):
             return ""
         return retval
 
@@ -2284,7 +2284,7 @@ class NXOSAaaGroupServerLine(BaseCfgLine):
     @property
     def server_private(self, re=re):
         retval = set([])
-        rgx_priv = re.compile("^\s+server-private\s+(\S+)\s")
+        rgx_priv = re.compile(r"^\s+server-private\s+(\S+)\s")
         for cobj in self.children:
             mm = rgx_priv.search(cobj.text)
             if not (mm is None):
@@ -2308,7 +2308,7 @@ class NXOSAaaLoginAuthenticationLine(BaseCfgLine):
         )
         self.group = self.re_match_typed(regex, group=2, result_type=str, default="")
         methods_str = self.re_match_typed(regex, group=3, result_type=str, default="")
-        self.methods = methods_str.strip().split("\s")
+        self.methods = methods_str.strip().split(r"\s")
 
     @classmethod
     def is_object_for(cls, line="", re=re):
@@ -2328,7 +2328,7 @@ class NXOSAaaEnableAuthenticationLine(BaseCfgLine):
         )
         self.group = self.re_match_typed(regex, group=2, result_type=str, default="")
         methods_str = self.re_match_typed(regex, group=3, result_type=str, default="")
-        self.methods = methods_str.strip().split("\s")
+        self.methods = methods_str.strip().split(r"\s")
 
     @classmethod
     def is_object_for(cls, line="", re=re):
@@ -2349,7 +2349,7 @@ class NXOSAaaCommandsAuthorizationLine(BaseCfgLine):
         )
         self.group = self.re_match_typed(regex, group=3, result_type=str, default="")
         methods_str = self.re_match_typed(regex, group=4, result_type=str, default="")
-        self.methods = methods_str.strip().split("\s")
+        self.methods = methods_str.strip().split(r"\s")
 
     @classmethod
     def is_object_for(cls, line="", re=re):
